aboutsummaryrefslogtreecommitdiff
path: root/examples/cl_convolution.cpp
diff options
context:
space:
mode:
authorAnthony Barbier <anthony.barbier@arm.com>2018-01-05 10:59:12 +0000
committerAnthony Barbier <anthony.barbier@arm.com>2018-11-02 16:42:33 +0000
commit6db0ff5b4bb49f834c7caa532a7feab228df10f9 (patch)
tree36c32ab3e94a86752d6b73c4a3503b191431d586 /examples/cl_convolution.cpp
parentfde97fb84943d0328c2c532d117e9b875149f27e (diff)
downloadComputeLibrary-6db0ff5b4bb49f834c7caa532a7feab228df10f9.tar.gz
COMPMID-771 Allow examples to be profiled
Change-Id: I180281e796e1670b9ad391d82d66ecde0119ef78 Note: this is for internal use only which is why I think the hackiness of RunExample.cpp is acceptable. Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/115154 Tested-by: Jenkins <bsgcomp@arm.com> Reviewed-by: Pablo Tello <pablo.tello@arm.com> Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com>
Diffstat (limited to 'examples/cl_convolution.cpp')
-rw-r--r--examples/cl_convolution.cpp106
1 files changed, 57 insertions, 49 deletions
diff --git a/examples/cl_convolution.cpp b/examples/cl_convolution.cpp
index b780193f14..24ad7c180e 100644
--- a/examples/cl_convolution.cpp
+++ b/examples/cl_convolution.cpp
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2016, 2017 ARM Limited.
+ * Copyright (c) 2016, 2018 ARM Limited.
*
* SPDX-License-Identifier: MIT
*
@@ -53,69 +53,77 @@ const int16_t gaussian5x5[] =
1, 4, 6, 4, 1
};
-void main_cl_convolution(int argc, const char **argv)
+class CLConvolutionExample : public Example
{
- PPMLoader ppm;
- CLImage src, tmp, dst;
-
- CLScheduler::get().default_init();
-
- if(argc < 2)
- {
- // Print help
- std::cout << "Usage: ./build/cl_convolution [input_image.ppm]\n\n";
- std::cout << "No input_image provided, creating a dummy 640x480 image\n";
- // Create an empty grayscale 640x480 image
- src.allocator()->init(TensorInfo(640, 480, Format::U8));
- }
- else
+public:
+ void do_setup(int argc, char **argv) override
{
- ppm.open(argv[1]);
- ppm.init_image(src, Format::U8);
- }
+ PPMLoader ppm;
- // Configure the temporary and destination images
- tmp.allocator()->init(*src.info());
- dst.allocator()->init(*src.info());
+ CLScheduler::get().default_init();
- CLConvolution3x3 conv3x3;
- CLConvolution5x5 conv5x5;
+ if(argc < 2)
+ {
+ // Print help
+ std::cout << "Usage: ./build/cl_convolution [input_image.ppm]\n\n";
+ std::cout << "No input_image provided, creating a dummy 640x480 image\n";
+ // Create an empty grayscale 640x480 image
+ src.allocator()->init(TensorInfo(640, 480, Format::U8));
+ }
+ else
+ {
+ ppm.open(argv[1]);
+ ppm.init_image(src, Format::U8);
+ }
- // Apply a Gaussian 3x3 filter to the source image followed by a Gaussian 5x5:
- conv3x3.configure(&src, &tmp, gaussian3x3, 0 /* Let arm_compute calculate the scale */, BorderMode::UNDEFINED);
- conv5x5.configure(&tmp, &dst, gaussian5x5, 0 /* Let arm_compute calculate the scale */, BorderMode::UNDEFINED);
+ // Configure the temporary and destination images
+ tmp.allocator()->init(*src.info());
+ dst.allocator()->init(*src.info());
- // Allocate all the images
- src.allocator()->allocate();
- tmp.allocator()->allocate();
- dst.allocator()->allocate();
- // Fill the input image with the content of the PPM image if a filename was provided:
- if(ppm.is_open())
- {
- ppm.fill_image(src);
- }
+ // Apply a Gaussian 3x3 filter to the source image followed by a Gaussian 5x5:
+ conv3x3.configure(&src, &tmp, gaussian3x3, 0 /* Let arm_compute calculate the scale */, BorderMode::UNDEFINED);
+ conv5x5.configure(&tmp, &dst, gaussian5x5, 0 /* Let arm_compute calculate the scale */, BorderMode::UNDEFINED);
- // Execute the functions:
- conv3x3.run();
- conv5x5.run();
-
- // Make sure all the OpenCL jobs are done executing:
- CLScheduler::get().sync();
+ // Allocate all the images
+ src.allocator()->allocate();
+ tmp.allocator()->allocate();
+ dst.allocator()->allocate();
+ // Fill the input image with the content of the PPM image if a filename was provided:
+ if(ppm.is_open())
+ {
+ ppm.fill_image(src);
+ output_filename = std::string(argv[1]) + "_out.ppm";
+ }
+ }
+ void do_run() override
+ {
+ // Execute the functions:
+ conv3x3.run();
+ conv5x5.run();
- // Save the result to file:
- if(ppm.is_open())
+ // Make sure all the OpenCL jobs are done executing:
+ CLScheduler::get().sync();
+ }
+ void do_teardown() override
{
- const std::string output_filename = std::string(argv[1]) + "_out.ppm";
- save_to_ppm(dst, output_filename); // save_to_ppm maps and unmaps the image to store as PPM
+ // Save the result to file:
+ if(!output_filename.empty())
+ {
+ save_to_ppm(dst, output_filename); // save_to_ppm maps and unmaps the image to store as PPM
+ }
}
-}
+ CLImage src{}, tmp{}, dst{};
+ CLConvolution3x3 conv3x3{};
+ CLConvolution5x5 conv5x5{};
+ std::string output_filename{};
+};
/** Main program for convolution test
*
* @param[in] argc Number of arguments
* @param[in] argv Arguments ( [optional] Path to PPM image to process )
*/
-int main(int argc, const char **argv)
+int main(int argc, char **argv)
{
- return utils::run_example(argc, argv, main_cl_convolution);
+ return utils::run_example<CLConvolutionExample>(argc, argv);
}